@@ -3,7 +3,7 @@
  *
  * A utility to search for articles within the Heise register.
  *
- * Copyright (C) 2002 Oliver Gantz <Oliver.Gantz@epost.de>
+ * Copyright (C) 2002 Oliver Gantz <Oliver.Gantz@ePost.de>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -54,10 +54,12 @@ public:
 	ArticleViewItem(QListView *parent = 0, const char *name = 0);
 	virtual ~ArticleViewItem();
 
-	virtual QString key(int column, bool ascending) const;
+	virtual QString key(int column, bool) const;
 
 	void setEntry(const RegEntry &e);
 
+	bool containsEntry(const RegEntry &e);
+
 	QString title() const;
 	QString subTitle() const;
 	QString magazine() const;
@@ -134,6 +136,7 @@ public:
 	KPopupMenu *contextMenu();
 
 public slots:
+	bool containsEntry(const RegEntry &entry);
 	void addEntry(const RegEntry &entry);
 
 private slots:
