@@ -3,7 +3,7 @@
  *
  * A utility to search for articles within the Heise register.
  *
- * Copyright (C) 2002 Oliver Gantz <Oliver.Gantz@epost.de>
+ * Copyright (C) 2002 Oliver Gantz <Oliver.Gantz@ePost.de>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -31,6 +31,7 @@
 #include <kiconloader.h>
 #include <klocale.h>
 #include <kfiledialog.h>
+#include <kurl.h>
 
 #include "global.h"
 #include "configure.h"
@@ -44,7 +45,7 @@ Configure::Configure(QWidget *parent, const char *name): KDialogBase(IconList, i
 	QGroupBox *gb;
 	QFrame *page;
 	QLabel *label;
-	QPushButton *browse;
+	QPushButton *ct_browse, *ix_browse;
 
 	config = kapp->config();
 
@@ -60,9 +61,14 @@ Configure::Configure(QWidget *parent, const char *name): KDialogBase(IconList, i
 	svbox = new QVBoxLayout(gb, spacingHint());
 	svbox->addSpacing(fontMetrics().height());
 
-	gen_tooltips = new QCheckBox(i18n("Show tooltips"), gb);
+	shbox = new QHBoxLayout(spacingHint());
+	svbox->addLayout(shbox);
+
+	gen_tooltips = new QCheckBox(i18n("Show &tooltips"), gb);
 	gen_tooltips->setMinimumSize(gen_tooltips->sizeHint());
-	svbox->addWidget(gen_tooltips);
+	shbox->addWidget(gen_tooltips);
+	shbox->addStretch();
+
 	svbox->activate();
 
 	vbox->addWidget(gb);
@@ -163,7 +169,7 @@ Configure::Configure(QWidget *parent, const char *name): KDialogBase(IconList, i
 
 	shbox = new QHBoxLayout(spacingHint());
 	svbox->addLayout(shbox);
-	sea_case_sensitive = new QCheckBox(i18n("Cas&e sensitive"), gb);
+	sea_case_sensitive = new QCheckBox(i18n("Ca&se sensitive"), gb);
 	sea_case_sensitive->setFixedSize(sea_case_sensitive->sizeHint());
 	shbox->addWidget(sea_case_sensitive);
 	shbox->addStretch();
@@ -193,6 +199,13 @@ Configure::Configure(QWidget *parent, const char *name): KDialogBase(IconList, i
 	sea_max_threshold->setEnabled(false);
 	shbox->addWidget(sea_max_threshold);
 
+	shbox = new QHBoxLayout(spacingHint());
+	svbox->addLayout(shbox);
+	sea_cumulative = new QCheckBox(i18n("C&umulative"), gb);
+	sea_cumulative->setFixedSize(sea_cumulative->sizeHint());
+	shbox->addWidget(sea_cumulative);
+	shbox->addStretch();
+
 	svbox->addStretch();
 	svbox->activate();
 
@@ -201,6 +214,8 @@ Configure::Configure(QWidget *parent, const char *name): KDialogBase(IconList, i
 	vbox->addStretch(1);
 	vbox->activate();
 
+	connect(sea_fuzzy, SIGNAL(toggled(bool)), this, SLOT(slotFuzzyToggled(bool)));
+
 
 	/* Page 3: Network */
 	page = addPage(i18n("Network"), i18n("Network Settings"), UserIcon(QString::fromLatin1("network")));
@@ -212,6 +227,7 @@ Configure::Configure(QWidget *parent, const char *name): KDialogBase(IconList, i
 	svbox = new QVBoxLayout(gb, spacingHint());
 	svbox->addSpacing(fontMetrics().height());
 
+//	grid = new QGridLayout(2, 3, spacingHint());
 	grid = new QGridLayout(2, 2, spacingHint());
 	svbox->addLayout(grid);
 
@@ -224,6 +240,12 @@ Configure::Configure(QWidget *parent, const char *name): KDialogBase(IconList, i
 	net_cturl->setMinimumSize(net_cturl->sizeHint());
 	grid->addWidget(net_cturl, 0, 1);
 
+//	ct_browse = new QPushButton(gb);
+//	ct_browse->setPixmap(SmallIcon("fileopen"));
+//	ct_browse->setAutoDefault(false);
+//	ct_browse->setFixedSize(ct_browse->sizeHint()+QSize(4, 4));
+//	grid->addWidget(ct_browse, 0, 2);
+
 	label = new QLabel(i18n("&iX Magazine:"), gb);
 	label->setMinimumSize(label->sizeHint());
 	grid->addWidget(label, 1, 0);
@@ -233,6 +255,12 @@ Configure::Configure(QWidget *parent, const char *name): KDialogBase(IconList, i
 	net_ixurl->setMinimumSize(net_ixurl->sizeHint());
 	grid->addWidget(net_ixurl, 1, 1);
 
+//	ix_browse = new QPushButton(gb);
+//	ix_browse->setPixmap(SmallIcon("fileopen"));
+//	ix_browse->setAutoDefault(false);
+//	ix_browse->setFixedSize(ix_browse->sizeHint()+QSize(4, 4));
+//	grid->addWidget(ix_browse, 1, 2);
+
 	grid->setColStretch(1, 1);
 
 	svbox->activate();
@@ -242,33 +270,53 @@ Configure::Configure(QWidget *parent, const char *name): KDialogBase(IconList, i
 	vbox->addStretch(1);
 	vbox->activate();
 
+//	connect(ct_browse, SIGNAL(clicked()), SLOT(slotBrowsectURL()));
+//	connect(ix_browse, SIGNAL(clicked()), SLOT(slotBrowseixURL()));
+
 
 	/* Page 4: c't-ROM */
-	page = addPage(i18n("c't-ROM"), i18n("c't-ROM Settings"), UserIcon(QString::fromLatin1("ctrom")));
+	page = addPage(i18n("CD-ROM"), i18n("CD-ROM Settings"), UserIcon(QString::fromLatin1("cdrom")));
 
 	vbox = new QVBoxLayout(page, spacingHint());
 
-	gb = new QGroupBox(i18n("c't-ROM"), page);
+	gb = new QGroupBox(i18n("CD-ROM Directories"), page);
 	svbox = new QVBoxLayout(gb, spacingHint());
 	svbox->addSpacing(fontMetrics().height());
 
-	shbox = new QHBoxLayout(spacingHint());
-	svbox->addLayout(shbox);
+	grid = new QGridLayout(2, 3, spacingHint());
+	svbox->addLayout(grid);
 
-	label = new QLabel(i18n("&CD mount point:"), gb);
-	label->setFixedSize(label->sizeHint());
-	shbox->addWidget(label);
+	label = new QLabel(i18n("c'&t-ROM directory:"), gb);
+	label->setMinimumSize(label->sizeHint());
+	grid->addWidget(label, 0, 0);
 
-	ctrom_mountpt = new QLineEdit(gb);
-	label->setBuddy(ctrom_mountpt);
-	ctrom_mountpt->setMinimumSize(ctrom_mountpt->sizeHint());
-	shbox->addWidget(ctrom_mountpt);
+	ctrom_dir = new QLineEdit(gb);
+	label->setBuddy(ctrom_dir);
+	ctrom_dir->setMinimumSize(ctrom_dir->sizeHint());
+	grid->addWidget(ctrom_dir, 0, 1);
 
-	browse = new QPushButton(gb);
-	browse->setPixmap(SmallIcon("fileopen"));
-	browse->setAutoDefault(false);
-	browse->setFixedSize(browse->sizeHint()+QSize(4, 4));
-	shbox->addWidget(browse);
+	ct_browse = new QPushButton(gb);
+	ct_browse->setPixmap(SmallIcon("fileopen"));
+	ct_browse->setAutoDefault(false);
+	ct_browse->setFixedSize(ct_browse->sizeHint()+QSize(4, 4));
+	grid->addWidget(ct_browse, 0, 2);
+
+	label = new QLabel(i18n("&iXPRESSed directory:"), gb);
+	label->setMinimumSize(label->sizeHint());
+	grid->addWidget(label, 1, 0);
+
+	ixpressed_dir = new QLineEdit(gb);
+	label->setBuddy(ixpressed_dir);
+	ixpressed_dir->setMinimumSize(ixpressed_dir->sizeHint());
+	grid->addWidget(ixpressed_dir, 1, 1);
+
+	ix_browse = new QPushButton(gb);
+	ix_browse->setPixmap(SmallIcon("fileopen"));
+	ix_browse->setAutoDefault(false);
+	ix_browse->setFixedSize(ix_browse->sizeHint()+QSize(4, 4));
+	grid->addWidget(ix_browse, 1, 2);
+
+	grid->setColStretch(1, 1);
 
 	svbox->activate();
 
@@ -281,9 +329,9 @@ Configure::Configure(QWidget *parent, const char *name): KDialogBase(IconList, i
 	shbox = new QHBoxLayout(spacingHint());
 	svbox->addLayout(shbox);
 
-	ctrom_extbrowser = new QCheckBox(i18n("Use alternative browser"), gb);
-	ctrom_extbrowser->setMinimumSize(ctrom_extbrowser->sizeHint());
-	shbox->addWidget(ctrom_extbrowser);
+	cdrom_extbrowser = new QCheckBox(i18n("Use alternative &browser"), gb);
+	cdrom_extbrowser->setMinimumSize(cdrom_extbrowser->sizeHint());
+	shbox->addWidget(cdrom_extbrowser);
 
 	shbox->addStretch();
 
@@ -292,11 +340,11 @@ Configure::Configure(QWidget *parent, const char *name): KDialogBase(IconList, i
 
 	shbox->addSpacing(19);
 
-	ctrom_browsercom = new QLineEdit(gb);
-	ctrom_browsercom->setMinimumSize(ctrom_browsercom->sizeHint());
-	ctrom_browsercom->setEnabled(false);
-	shbox->addWidget(ctrom_browsercom);
-	
+	cdrom_browsercom = new QLineEdit(gb);
+	cdrom_browsercom->setMinimumSize(cdrom_browsercom->sizeHint());
+	cdrom_browsercom->setEnabled(false);
+	shbox->addWidget(cdrom_browsercom);
+
 	svbox->activate();
 
 	vbox->addWidget(gb);
@@ -304,16 +352,16 @@ Configure::Configure(QWidget *parent, const char *name): KDialogBase(IconList, i
 	vbox->addStretch(1);
 	vbox->activate();
 
+	connect(ct_browse, SIGNAL(clicked()), SLOT(slotBrowsectDir()));
+	connect(ix_browse, SIGNAL(clicked()), SLOT(slotBrowseixDir()));
+	connect(cdrom_extbrowser, SIGNAL(toggled(bool)), this, SLOT(slotExternalToggled(bool)));
+
 
 	config->setGroup(QString::fromLatin1(ID_PREF_GROUP_GENERAL));
 	if (config->readBoolEntry(ID_PREF_GEN_TOOLTIPS, PREF_GEN_TOOLTIPS)) {
 		QToolTip::add(gen_tooltips, i18n("Show tooltips in dialogs"));
 	}
 
-	connect(sea_fuzzy, SIGNAL(toggled(bool)), this, SLOT(slotFuzzyToggled(bool)));
-	connect(ctrom_extbrowser, SIGNAL(toggled(bool)), this, SLOT(slotExternalToggled(bool)));
-	connect(browse, SIGNAL(clicked()), SLOT(slotBrowseMountPt()));
-
 	reset();
 }
 
@@ -335,12 +383,14 @@ void Configure::slotDefault()
 	sea_ixmag->setChecked(PREF_SEA_IXMAG);
 	sea_case_sensitive->setChecked(PREF_SEA_CASE);
 	sea_fuzzy->setChecked(PREF_SEA_FUZZY);
+	sea_cumulative->setChecked(PREF_SEA_CUMUL);
 	sea_threshold->setValue(PREF_SEA_THRESHOLD);
 	net_cturl->setText(PREF_NET_CTURL);
 	net_ixurl->setText(PREF_NET_IXURL);
-	ctrom_mountpt->setText(QString::fromLatin1(PREF_CTROM_MOUNTPT));
-	ctrom_extbrowser->setChecked(PREF_CTROM_ALTBROWSER);
-	ctrom_browsercom->setText(QString::fromLatin1(PREF_CTROM_BROWSERCOM));
+	ctrom_dir->setText(QString::fromLatin1(PREF_CDROM_CTDIR));
+	ixpressed_dir->setText(QString::fromLatin1(PREF_CDROM_IXDIR));
+	cdrom_extbrowser->setChecked(PREF_CDROM_ALTBROWSER);
+	cdrom_browsercom->setText(QString::fromLatin1(PREF_CDROM_BROWSERCOM));
 }
 
 
@@ -359,16 +409,18 @@ void Configure::slotApply()
 	config->writeEntry(ID_PREF_SEA_IXMAG, sea_ixmag->isChecked());
 	config->writeEntry(ID_PREF_SEA_CASE, sea_case_sensitive->isChecked());
 	config->writeEntry(ID_PREF_SEA_FUZZY, sea_fuzzy->isChecked());
+	config->writeEntry(ID_PREF_SEA_CUMUL, sea_cumulative->isChecked());
 	config->writeEntry(ID_PREF_SEA_THRESHOLD, sea_threshold->value());
 
 	config->setGroup(QString::fromLatin1(ID_PREF_GROUP_NETWORK));
 	config->writeEntry(ID_PREF_NET_CTURL, net_cturl->text());
 	config->writeEntry(ID_PREF_NET_IXURL, net_ixurl->text());
 
-	config->setGroup(QString::fromLatin1(ID_PREF_GROUP_CTROM));
-	config->writeEntry(ID_PREF_CTROM_MOUNTPT, ctrom_mountpt->text());
-	config->writeEntry(ID_PREF_CTROM_ALTBROWSER, ctrom_extbrowser->isChecked());
-	config->writeEntry(ID_PREF_CTROM_BROWSERCOM, ctrom_browsercom->text());
+	config->setGroup(QString::fromLatin1(ID_PREF_GROUP_CDROM));
+	config->writeEntry(ID_PREF_CDROM_CTDIR, ctrom_dir->text());
+	config->writeEntry(ID_PREF_CDROM_IXDIR, ixpressed_dir->text());
+	config->writeEntry(ID_PREF_CDROM_ALTBROWSER, cdrom_extbrowser->isChecked());
+	config->writeEntry(ID_PREF_CDROM_BROWSERCOM, cdrom_browsercom->text());
 
 	config->sync();
 }
@@ -397,16 +449,18 @@ void Configure::reset()
 	sea_ixmag->setChecked(config->readBoolEntry(ID_PREF_SEA_IXMAG, PREF_SEA_IXMAG));
 	sea_case_sensitive->setChecked(config->readBoolEntry(ID_PREF_SEA_CASE, PREF_SEA_CASE));
 	sea_fuzzy->setChecked(config->readBoolEntry(ID_PREF_SEA_FUZZY, PREF_SEA_FUZZY));
+	sea_cumulative->setChecked(config->readBoolEntry(ID_PREF_SEA_CUMUL, PREF_SEA_CUMUL));
 	sea_threshold->setValue(config->readNumEntry(ID_PREF_SEA_THRESHOLD, PREF_SEA_THRESHOLD));
 
 	config->setGroup(QString::fromLatin1(ID_PREF_GROUP_NETWORK));
 	net_cturl->setText(config->readEntry(ID_PREF_NET_CTURL, QString::fromLatin1(PREF_NET_CTURL)));
 	net_ixurl->setText(config->readEntry(ID_PREF_NET_IXURL, QString::fromLatin1(PREF_NET_IXURL)));
 
-	config->setGroup(QString::fromLatin1(ID_PREF_GROUP_CTROM));
-	ctrom_mountpt->setText(config->readEntry(ID_PREF_CTROM_MOUNTPT, QString::fromLatin1(PREF_CTROM_MOUNTPT)));
-	ctrom_extbrowser->setChecked(config->readBoolEntry(ID_PREF_CTROM_ALTBROWSER, PREF_CTROM_ALTBROWSER));
-	ctrom_browsercom->setText(config->readEntry(ID_PREF_CTROM_BROWSERCOM, QString::fromLatin1(PREF_CTROM_BROWSERCOM)));
+	config->setGroup(QString::fromLatin1(ID_PREF_GROUP_CDROM));
+	ctrom_dir->setText(config->readEntry(ID_PREF_CDROM_CTDIR, QString::fromLatin1(PREF_CDROM_CTDIR)));
+	ixpressed_dir->setText(config->readEntry(ID_PREF_CDROM_IXDIR, QString::fromLatin1(PREF_CDROM_IXDIR)));
+	cdrom_extbrowser->setChecked(config->readBoolEntry(ID_PREF_CDROM_ALTBROWSER, PREF_CDROM_ALTBROWSER));
+	cdrom_browsercom->setText(config->readEntry(ID_PREF_CDROM_BROWSERCOM, QString::fromLatin1(PREF_CDROM_BROWSERCOM)));
 }
 
 
@@ -417,21 +471,54 @@ void Configure::slotFuzzyToggled(bool on)
 	sea_max_threshold->setEnabled(on);
 }
 
-
-void Configure::slotBrowseMountPt()
+/*
+void Configure::slotBrowsectURL()
 {
-	QString s = ctrom_mountpt->text();
+	KURL url;
+
+	url = KFileDialog::getExistingURL(net_cturl->text(), this);
+	if (!url.isEmpty())
+		net_cturl->setText(url.prettyURL());
+}
+
+
+void Configure::slotBrowseixURL()
+{
+	KURL url;
+
+	url = KFileDialog::getExistingURL(net_ixurl->text(), this);
+	if (!url.isEmpty())
+		net_ixurl->setText(url.prettyURL());
+}
+*/
+
+void Configure::slotBrowsectDir()
+{
+	QString s = ctrom_dir->text();
 
 	if (s.isEmpty())
 		s = QDir::currentDirPath();
 
 	s = KFileDialog::getExistingDirectory(s, this);
 	if (!s.isEmpty())
-		ctrom_mountpt->setText(s);
+		ctrom_dir->setText(s);
+}
+
+
+void Configure::slotBrowseixDir()
+{
+	QString s = ixpressed_dir->text();
+
+	if (s.isEmpty())
+		s = QDir::currentDirPath();
+
+	s = KFileDialog::getExistingDirectory(s, this);
+	if (!s.isEmpty())
+		ixpressed_dir->setText(s);
 }
 
 
 void Configure::slotExternalToggled(bool on)
 {
-	ctrom_browsercom->setEnabled(on);
+	cdrom_browsercom->setEnabled(on);
 }
