@@ -3,7 +3,7 @@
  *
  * A utility to search for articles within the Heise register.
  *
- * Copyright (C) 2002 Oliver Gantz <Oliver.Gantz@epost.de>
+ * Copyright (C) 2002 Oliver Gantz <Oliver.Gantz@ePost.de>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -69,6 +69,7 @@ KHeiseReg::KHeiseReg(QWidget *parent, const char *name): KMainWindow(parent, nam
 	view->setViewAction(articleView);
 	view->plugContextMenu(articleView);
 	view->plugContextMenu(articlePrint);
+	view->plugContextMenu(articleClear);
 	setCentralWidget(view);
 
 	readOptions();
@@ -126,6 +127,11 @@ void KHeiseReg::initActions()
 	articlePrint->setWhatsThis(i18n("Click this button to print the current search result list.<br><br>" \
 		"You can also select the command <b>Print List</b> from the \"Article\" menu."));
 	articlePrint->setEnabled(false);
+	articleClear = new KAction(i18n("&Clear List"), "view_remove", CTRL+Key_C, this, SLOT(slotArticleClear()), actionCollection(), "article_clear");
+	Q_CHECK_PTR(articleClear);
+	articleClear->setWhatsThis(i18n("Click this button to clear the current search result list.<br><br>" \
+		"You can also select the command <b>Clear List</b> from the \"Article\" menu."));
+	articleClear->setEnabled(false);
 
 	settingsShowToolbar = KStdAction::showToolbar(this, SLOT(slotSettingsShowToolbar()), actionCollection());
 	settingsShowStatusbar = KStdAction::showStatusbar(this, SLOT(slotSettingsShowStatusbar()), actionCollection());
@@ -153,6 +159,7 @@ void KHeiseReg::initMenuBar()
 	articleSearch->plug(articleMenu);
 	articleView->plug(articleMenu);
 	articlePrint->plug(articleMenu);
+	articleClear->plug(articleMenu);
 
 	settingsMenu = new QPopupMenu(0, "settingsmenu");
 	Q_CHECK_PTR(settingsMenu);
@@ -178,6 +185,7 @@ void KHeiseReg::initToolBar()
 	articleSearch->plug(toolBar());
 	articleView->plug(toolBar());
 	articlePrint->plug(toolBar());
+	articleClear->plug(toolBar());
 	toolBar()->insertSeparator();
 	settingsConfigure->plug(toolBar());
 	toolBar()->insertSeparator();
@@ -213,9 +221,10 @@ void KHeiseReg::slotFileQuit()
 
 void KHeiseReg::slotArticleSearch()
 {
-	if (searchdlg->isVisible())
+	if (searchdlg->isVisible()) {
 		searchdlg->raise();
-	else
+		searchdlg->setActiveWindow();
+	} else
 		searchdlg->show();
 }
 
@@ -228,8 +237,13 @@ void KHeiseReg::slotArticleView()
 	QDir checkCD;
 	int page, count;
 
-	config->setGroup(QString::fromLatin1(ID_PREF_GROUP_CTROM));
-	fname = config->readEntry(ID_PREF_CTROM_MOUNTPT, QString::fromLatin1(PREF_CTROM_MOUNTPT)) + "/html";
+	config->setGroup(QString::fromLatin1(ID_PREF_GROUP_CDROM));
+	if (view->articleMagazine() == REG_MAGAZINE_CT)
+		fname = config->readEntry(ID_PREF_CDROM_CTDIR, QString::fromLatin1(PREF_CDROM_CTDIR));
+	else
+		fname = config->readEntry(ID_PREF_CDROM_IXDIR, QString::fromLatin1(PREF_CDROM_IXDIR));
+
+	fname += "/html";
 
 	checkCD.setPath(fname);
 	if (!checkCD.isReadable()) {
@@ -264,10 +278,9 @@ void KHeiseReg::slotArticleView()
 
 	url.setFileName(fname + s);
 
-	config->setGroup(ID_PREF_GROUP_CTROM);
-	if (config->readBoolEntry(ID_PREF_CTROM_ALTBROWSER, PREF_CTROM_ALTBROWSER)) {
+	if (config->readBoolEntry(ID_PREF_CDROM_ALTBROWSER, PREF_CDROM_ALTBROWSER)) {
 		int pos;
-		QString com = config->readEntry(ID_PREF_CTROM_BROWSERCOM, PREF_CTROM_BROWSERCOM);
+		QString com = config->readEntry(ID_PREF_CDROM_BROWSERCOM, PREF_CDROM_BROWSERCOM);
 
 		while ((pos = com.find("%u")) != -1)
 			com.replace(pos, 2, url.url());
@@ -371,6 +384,12 @@ void KHeiseReg::slotArticlePrint()
 }
 
 
+void KHeiseReg::slotArticleClear()
+{
+	view->clear();
+}
+
+
 void KHeiseReg::slotSettingsShowToolbar()
 {
 	if (settingsShowToolbar->isChecked())
@@ -409,9 +428,9 @@ void KHeiseReg::slotSettingsConfigure()
 }
 
 
-void KHeiseReg::slotHasSelection(bool ct)
+void KHeiseReg::slotHasSelection(bool on)
 {
-	articleView->setEnabled(ct);
+	articleView->setEnabled(on);
 }
 
 
@@ -433,6 +452,7 @@ void KHeiseReg::slotStatusItems(int items)
 	statusBar()->changeItem(i18n(" %1 Articles ").arg(KGlobal::locale()->formatNumber((double)items, 0)), ID_STATUS_ITEMS);
 	slotStatusMsg(i18n("Ready."));
 	articlePrint->setEnabled(items > 0);
+	articleClear->setEnabled(items > 0);
 }
 
 
