@@ -3,7 +3,7 @@
  *
  * A utility to search for articles within the Heise register.
  *
- * Copyright (C) 2002 Oliver Gantz <Oliver.Gantz@epost.de>
+ * Copyright (C) 2002 Oliver Gantz <Oliver.Gantz@ePost.de>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -48,7 +48,9 @@ public:
 	void saveOptions();
 
 	void search(const RegMask &mask);
+	void clear();
 
+	int articleMagazine();
 	int articleYear();
 	int articleEdition();
 	int articlePage();
@@ -60,7 +62,7 @@ public:
 
 private slots:
 	void currentChangedSlot(QListViewItem *item);
-	void executedSlot(QListViewItem *item);
+	void executedSlot(QListViewItem *);
 
 signals:
 	void items(int);
@@ -71,10 +73,14 @@ private:
 	QLabel *title, *subtitle, *author, *editor, *magazine, *edition, *page, *links;
 	KAction *viewaction;
 
-	int cur_edition, cur_year, cur_page;
+	int cur_mag, cur_edition, cur_year, cur_page;
 };
 
 
+inline int KHeiseView::articleMagazine()
+{	return cur_mag; }
+
+
 inline int KHeiseView::articleYear()
 {	return cur_year % 100; }
 
