@@ -3,7 +3,7 @@
  *
  * A utility to search for articles within the Heise register.
  *
- * Copyright (C) 2002 Oliver Gantz <Oliver.Gantz@epost.de>
+ * Copyright (C) 2002 Oliver Gantz <Oliver.Gantz@ePost.de>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -438,6 +438,8 @@ unsigned char RegEntry::magazine() const
 		return REG_MAGAZINE_CT;
 	if (*m_lines[REG_LINE_MAGYEAR] == 'i')
 		return REG_MAGAZINE_IX;
+	if (*m_lines[REG_LINE_MAGYEAR] == 'g')
+		return REG_MAGAZINE_GATEWAY;
 
 	return REG_MAGAZINE_NONE;
 }
